# -*- coding: utf-8 -*-

import numpy as np
import pandas as pd
import matplotlib.pyplot as plt
import seaborn as sns
import pylab as pl
import re
import itertools


def plot(filename, samplenr):
    sns.set_context('paper')
    sns.set_style('ticks')
    fig, ax = pl.subplots()
    etas = np.array([70.,65., 60., 55., 50.]) * (np.pi / 180.)
    data = pd.read_csv(filename)
    strats = ['Direct sampling', 'Z-guiding', 'AIS w CE ind. (batch=10,q=0.100000)']

    palette = itertools.cycle(sns.color_palette())

    for i,strat in enumerate(strats):
        hist = data[data['Strategy']==strat]['choice histogram']
        meanh = []
        for row in hist:
            junkers = re.compile('[["\]]')
            h = list(map(pd.to_numeric, junkers.sub('',row).split()))
            meanh.append(h)
        hist = np.mean(np.array(meanh),axis=0)
        vhist = np.var(np.array(meanh), axis=0)
        #ax.stem(range(len(hist)), hist, label=strat)
        xs = np.array(range(len(hist)))
        width = 0.25
        if (strat == 'Z-guiding'):
            strat = 'TUTS guiding'
        rects1 = ax.bar(xs+i*width, hist, width, yerr=np.sqrt(vhist),color=next(palette), label=strat, alpha=0.3)

        #ax.fill_between(range(len(hist)), hist -np.sqrt(vhist), hist+np.sqrt(vhist), alpha=0.1)
    pl.xticks(xs+width*3./2., map(lambda x: '%.2f'%(x),etas))
    ax.set_xlabel(r'Angles $\eta$')
    ax.set_ylabel('Frequency of occurrence')
    ax.legend(loc=9, bbox_to_anchor=(0.5, -0.2), ncol=3)
    sns.despine(offset=5)
    #pl.show()
    pl.savefig('Histogramm_nsamples_'+str(samplenr)+'_nrepetitions_10000.pdf', format='pdf', bbox_inches="tight")
    pl.savefig('Histogramm_nsamples_'+str(samplenr)+'_nrepetitions_10000.png', format='png', bbox_inches="tight")
    #a=raw_input()
    return


if __name__ == "__main__":
    samples = [1000]
    for sample in samples:
        data = []
        filename = str('evaluation_results_nsamples_'+str(sample) +'_nrepetitions_10000.csv')
        plot(filename, sample)


    

